<?php
/***
 * Custom Color Options
 *
 * Get custom colors from theme options and embed CSS color settings 
 * in the <head> area of the theme. 
 *
 */
// Add Custom Colors
add_action('wp_head', 'nichebarn_custom_colors');
function nichebarn_custom_colors() { 
	// Get Theme Options from Database
	$theme_options = nichebarn_theme_options();
	// Set Color CSS Variable
	$color_css = '';
	if ( isset($theme_options['topnav_color']) and $theme_options['topnav_color'] <> '#373c43' ) : 
		$color_css .= '
			#topnav, #topnav-icon, #topheader {
				background: '. $theme_options['topnav_color'] .';
			}';
	endif;
	if ( isset($theme_options['topnav_current']) and $theme_options['topnav_current'] <> '#4a525d' ) : 
		$color_css .= '
			#topnav-menu li.current_page_item a, #topnav-menu li.current-menu-item a {
				background: '. $theme_options['topnav_current'] .';
			}';
	endif;
	if ( isset($theme_options['topnav_hover']) and $theme_options['topnav_hover'] <> '#121212' ) : 
		$color_css .= '
			#topnav-menu a:hover, #topnav-menu li a:hover {
				background: '. $theme_options['topnav_hover'] .';
			}';
	endif;
	if ( isset($theme_options['topnav_dropdown']) and $theme_options['topnav_dropdown'] <> '#303030' ) : 
		$color_css .= '
			#topnav-menu .sub-menu, #topnav-menu .children {
				background-color: '. $theme_options['topnav_dropdown'] .';
			}';
	endif;
	if ( isset($theme_options['topnav_drophov']) and $theme_options['topnav_drophov'] <> '#121212' ) : 
		$color_css .= '
			ul#topnav-menu ul a:hover, #topnav-menu ul ul a:hover, ul#topnav-menu ul a:focus, #topnav-menu ul ul a:focus {
				background-color: '. $theme_options['topnav_drophov'] .';
			}';
	endif;
	if ( isset($theme_options['topnav_dropbor']) and $theme_options['topnav_dropbor'] <> '#777777' ) : 
		$color_css .= '
			ul#topnav-menu ul a, #topnav-menu ul ul a {
				border-top: 1px solid'. $theme_options['topnav_dropbor'] .';
			}
			#topnav-menu .sub-menu, #topnav-menu .children {
				border-color: '. $theme_options['topnav_dropbor'] .';
			}';
	endif;
	if ( isset($theme_options['topnav_text_color']) and $theme_options['topnav_text_color'] <> '#f9f9f9' ) : 
		$color_css .= '
			#topnav-menu a:link, #topnav-menu a:visited, #header-social-icons .social-icons-menu li a:before {
				color: '. $theme_options['topnav_text_color'] .';
			}';
	endif;
	if ( isset($theme_options['navi_text_color']) and $theme_options['navi_text_color'] <> '#f9f9f9' ) : 
		$color_css .= '
			.nav-menu li a, .site-header .search-form::before, .nav-menu .current_page_item > a, .nav-menu .current_page_ancestor > a, 
			.nav-menu .current-menu-item > a, .nav-menu .current-menu-ancestor > a {
				color: '. $theme_options['navi_text_color'] .';
			}';
	endif;
	if ( isset($theme_options['navi_color']) and $theme_options['navi_color'] <> '#3c3c3c' ) : 
		$color_css .= '
			#navi-wrap, .stickynav {
				background: '. $theme_options['navi_color'] .';
			}';
	endif;
	if ( isset($theme_options['navi_wrapper']) and $theme_options['navi_wrapper'] <> '#c9c9c9' ) : 
		$color_css .= '
			#navi-wrap, .stickynav {
				border-top: 3px solid '. $theme_options['navi_wrapper'] .';
				border-bottom: 3px solid '. $theme_options['navi_wrapper'] .';
			}';
	endif;
	if ( isset($theme_options['navi_border']) and $theme_options['navi_border'] <> '#c9c9c9' ) : 
		$color_css .= '
			.nav-menu li {
				border-right: 1px solid '. $theme_options['navi_border'] .';
			}
			.nav-menu li:first-child {
				border-left: 1px solid '. $theme_options['navi_border'] .';
			}';
	endif;
	if ( isset($theme_options['navi_hover']) and $theme_options['navi_hover'] <> '#121212' ) : 
		$color_css .= '
			.nav-menu li:hover > a, .nav-menu li a:hover, .nav-menu li:focus > a, .nav-menu li a:focus {
				background: '. $theme_options['navi_hover'] .';
			}';
	endif;
	if ( isset($theme_options['navi_dropdown']) and $theme_options['navi_dropdown'] <> '#303030' ) : 
		$color_css .= '
			.nav-menu .sub-menu, .nav-menu .children {
				background: '. $theme_options['navi_dropdown'] .';
			}';
	endif;
	if ( isset($theme_options['navi_drophov']) and $theme_options['navi_drophov'] <> '#303030' ) : 
		$color_css .= '
			ul.nav-menu ul a:hover, .nav-menu ul ul a:hover, ul.nav-menu ul a:focus, .nav-menu ul ul a:focus {
				background-color: '. $theme_options['navi_drophov'] .';
			}';
	endif;
	if ( isset($theme_options['navi_dropdown_border']) and $theme_options['navi_dropdown_border'] <> '#777777' ) : 
		$color_css .= '
			.nav-menu .sub-menu, .nav-menu .children {
				border: 2px solid '. $theme_options['navi_dropdown_border'] .';
			}
			.nav-menu .sub-menu ul, .nav-menu .children ul {
				border-left: 1px solid '. $theme_options['navi_dropdown_border'] .';
			}
			ul.nav-menu ul a, .nav-menu ul ul a {
				border-top: 1px solid '. $theme_options['navi_dropdown_border'] .';
			}
			.toggled-on li, .toggled-on .children {
				border-top: 1px solid '. $theme_options['navi_dropdown_border'] .';
				border-left: 1px solid '. $theme_options['navi_dropdown_border'] .';
			}';
	endif;
	if ( isset($theme_options['header_backgr']) and $theme_options['header_backgr'] <> '' ) : 
		$color_css .= '
			#header-wrap {
				background: '. $theme_options['header_backgr'] .';
			}';
	endif;
	if ( isset($theme_options['header_topbo']) and $theme_options['header_topbo'] <> '#e5e5e5' ) : 
		$color_css .= '
			#header-wrap {
				border-top: 10px solid '. $theme_options['header_topbo'] .';
			}';
	endif;
	if ( isset($theme_options['default_text_color']) and $theme_options['default_text_color'] <> '#111111' ) : 
		$color_css .= '
			body, input, textarea {
				color: '. $theme_options['default_text_color'] .';
			}';
	endif;
	if ( isset($theme_options['title_color']) and $theme_options['title_color'] <> '#3c3c3c' ) : 
		$color_css .= '
			.page-title, .post-title, 
			.post-title a:link, .post-title a:visited, .archive-title span, .archive-title {
				color: '. $theme_options['title_color'] .';
			}
			.post-title a:hover, .post-title a:active {
				color: '. $theme_options['title_color'] .';
			}';
	endif;
	if ( isset($theme_options['link_color']) and $theme_options['link_color'] <> '#0066cc' ) : 
	
		$color_css .= '
			a, a:link, a:visited, .comment a:link, .comment a:visited,
			.post-pagination a:link, .post-pagination a:visited, #image-nav .nav-previous a, #image-nav .nav-next a, .postmeta a:link, .postmeta a:visited {
				color: '. $theme_options['link_color'] .';
			}
			.post-pagination .current {
				background-color: '. $theme_options['link_color'] .';
			}';
	endif;
	if ( isset($theme_options['site_title_color']) and $theme_options['site_title_color'] <> '#3c3c3c' ) : 
		$color_css .= '
			#logo .site-title, #logo a:hover .site-title {
				color: '. $theme_options['site_title_color'] .';
			}';
	endif;
	if ( isset($theme_options['site_tagline_color']) and $theme_options['site_tagline_color'] <> '#444' ) : 
		$color_css .= '
			#logo .site-description {
				color: '. $theme_options['site_tagline_color'] .';
			}';
	endif;
	if ( isset($theme_options['wrapper_color']) and $theme_options['wrapper_color'] <> '#ffffff' ) : 
		$color_css .= '
			#frontpage-magazine-widgets .widget {
				background: '. $theme_options['wrapper_color'] .';
			}';
	endif;
	if ( isset($theme_options['line_borders_color']) and $theme_options['line_borders_color'] <> '#eaeaea' ) : 
		$color_css .= '
			input, textarea {
				border: 1px solid '. $theme_options['line_borders_color'] .';
			}
			.widget-category-posts .small-post, .type-post, .type-page, .type-attachment, .archive-title  {
				border-bottom: 1px solid '. $theme_options['line_borders_color'] .';
			}';
	endif;
	if ( isset($theme_options['body_buttons_color']) and $theme_options['body_buttons_color'] <> '#ffffff' ) : 
		$color_css .= '
			#sidebar .widget ul:not(.w-icon) li::before, .postmeta span::before, .postinfo span::before {
				color: '. $theme_options['body_buttons_color'] .';
			}
			#commentform #submit {
				background: '. $theme_options['body_buttons_color'] .';
			}
			.more-link, .more-link:link, .more-link:visited, .more-link:hover, .more-link:active {
				background-color: '. $theme_options['body_buttons_color'] .';
			}';
	endif;
	if ( isset($theme_options['widget_title_color']) and $theme_options['widget_title_color'] <> '#ffffff' ) : 
		$color_css .= '
			#sidebar .widgettitle, #frontpage-magazine-widgets .widget .widgettitle, .widget-tabnavi, .widgettitle a:visited, .widget-tabnav li a:link, .widget-tabnav li a:visited {
				color: '. $theme_options['widget_title_color'].';
			}';
	endif;
	if ( isset($theme_options['widget_header_color']) and $theme_options['widget_header_color'] <> '#3c3c3c' ) : 
		$color_css .= '
			#sidebar .widgettitle, #frontpage-magazine-widgets .widget .widgettitle, .widget-tabnavi, .widget-tabnavi {
				background: '. $theme_options['widget_header_color'] .';
				border: 1px solid '. $theme_options['widget_header_color'] .';
			}';
	endif;
	if ( isset($theme_options['widget_link_color']) and $theme_options['widget_link_color'] <> '#3c3c3c' ) : 
		$color_css .= '
			#sidebar .widget a:link, #sidebar .widget a:visited {
				color: '. $theme_options['widget_link_color'].';
			}';
	endif;
	if ( isset($theme_options['widget_text_color']) and $theme_options['widget_text_color'] <> '#3c3c3c' ) : 
		$color_css .= '
			.widget ul {
				color: '. $theme_options['widget_text_color'].';
			}';
	endif;
	if ( isset($theme_options['widget_backgr_color']) and $theme_options['widget_backgr_color'] <> '#FFFFFF' ) : 
		$color_css .= '
			#sidebar .widget {
				background: '. $theme_options['widget_backgr_color'].';
			}';	
	endif;
	if ( isset($theme_options['sidebar_background']) and $theme_options['sidebar_background'] <> '#f3f3f3' ) : 
		$color_css .= '
			#sidebar {
				background: '. $theme_options['sidebar_background'].';
			}';	
	endif;
	if ( isset($theme_options['footer_widgets_color']) and $theme_options['footer_widgets_color'] <> '#333333' ) : 
		$color_css .= '
			#footer-widgets-bg {
				background-color: '.  $theme_options['footer_widgets_color'] .';
			}';
	endif;
	if ( isset($theme_options['footer_texts_borders']) and $theme_options['footer_texts_borders'] <> '#454444' ) : 
		$color_css .= '
			#footer-widgets .widget ul li {
				border-bottom: 1px solid '.  $theme_options['footer_texts_borders'] .';
			}';
	endif;	
	if ( isset($theme_options['footer_widgets_texts']) and $theme_options['footer_widgets_texts'] <> '#CCCCCC' ) : 
		$color_css .= '
			#footer-widgets .widget a:link, #footer-widgets .widget a:visited {
				color: '.  $theme_options['footer_widgets_texts'] .';
			}';
	endif;
	if ( isset($theme_options['footer_texts_colol']) and $theme_options['footer_texts_colol'] <> '#c6c6c6' ) : 
		$color_css .= '
			#footernav-menu li {
				border-right: 1px solid '. $theme_options['footer_texts_colol'] .';
			}
			#footer-text, #footer-text a:link, #footer-text a:visited, #footernav-menu a:link, #footernav-menu a:visited {
				color: '.  $theme_options['footer_texts_colol'] .';
			}';
			
	endif;
	if ( isset($theme_options['footer_color']) and $theme_options['footer_color'] <> '#121212' ) : 
		$color_css .= '
			#footer {
				background: '. $theme_options['footer_color'] .';
			}';
	endif;
	if ( isset($theme_options['footer_top_brdr']) and $theme_options['footer_top_brdr'] <> '#454444' ) : 
		$color_css .= '
			#footer {
				border-top: 1px solid '. $theme_options['footer_top_brdr'] .';
			}';
	endif;
	// Print Color CSS
	if ( isset($color_css) and $color_css <> '' ) :
		echo '<style type="text/css">';
		echo $color_css;
		echo '</style>';
	endif;
}?>