<?php
/**
 * Register Theme Font section, settings and controls for Theme Customizer
 *
 */

// Add Theme Fonts section to Customizer
add_action( 'customize_register', 'nichebarn_customize_register_font_settings' );

function nichebarn_customize_register_font_settings( $wp_customize ) {

	// Add Section for Theme Fonts
	$wp_customize->add_section( 'nichebarn_section_fonts', array(
        'title'    => __( 'Fonts', 'nichebarn' ),
        'priority' => 101,
		)
	);
	
	// Get Default Fonts from settings
	$default_options = nichebarn_default_options();

	// Deactivate Google Font setting
	$wp_customize->add_setting( 'nichebarn_theme_options[default_fonts]', array(
        'default'           => '',
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'esc_attr'
        )
    );
    $wp_customize->add_control( new Nichebarn_Customize_Header_Control(
        $wp_customize, 'nichebarn_control_default_fonts', array(
            'label' => __( 'Enable Google Fonts?', 'nichebarn' ),
            'section' => 'nichebarn_section_fonts',
            'settings' => 'nichebarn_theme_options[default_fonts]',
            'priority' => 1,
            )
        )
    );
	$wp_customize->add_setting( 'nichebarn_theme_options[deactivate_google_fonts]', array(
        'default'           => false,
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_checkbox'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_deactivate_google_fonts', array(
        'label'    => __( 'Check this to activate Google Fonts. If uncheck, only Browser Safe Fonts is active.', 'nichebarn' ),
        'section'  => 'nichebarn_section_fonts',
        'settings' => 'nichebarn_theme_options[deactivate_google_fonts]',
        'type'     => 'checkbox',
		'priority' => 2,
		)
	);
		// Add settings and controls for theme fonts
	$wp_customize->add_setting( 'nichebarn_theme_options[text_font]', array(
        'default'           => $default_options['text_font'],
		'type'           	=> 'option',
        'transport'         => 'postMessage',
        'sanitize_callback' => 'esc_attr'
		)
	);
	$wp_customize->add_control( new Nichebarn_Customize_Font_Control( 
		$wp_customize, 'text_font', array(
			'label'      => __( 'Default Text Font', 'nichebarn' ),
			'section'    => 'nichebarn_section_fonts',
			'settings'   => 'nichebarn_theme_options[text_font]',
			'priority' => 3,
		) ) 
	);
	
	$wp_customize->add_setting( 'nichebarn_theme_options[site_title_font]', array(
        'default'           => $default_options['site_title_font'],
		'type'           	=> 'option',
        'transport'         => 'postMessage',
        'sanitize_callback' => 'esc_attr'
		)
	);
	$wp_customize->add_control( new Nichebarn_Customize_Font_Control( 
		$wp_customize, 'site_title_font', array(
			'label'      => __( 'Site Title Font', 'nichebarn' ),
			'section'    => 'nichebarn_section_fonts',
			'settings'   => 'nichebarn_theme_options[site_title_font]',
			'priority' => 4,
		) ) 
	);
	
	$wp_customize->add_setting( 'nichebarn_theme_options[title_font]', array(
        'default'           => $default_options['title_font'],
		'type'           	=> 'option',
        'transport'         => 'postMessage',
        'sanitize_callback' => 'esc_attr'
		)
	);
	$wp_customize->add_control( new Nichebarn_Customize_Font_Control( 
		$wp_customize, 'title_font', array(
			'label'      => __( 'Post/Page Title Font', 'nichebarn' ),
			'section'    => 'nichebarn_section_fonts',
			'settings'   => 'nichebarn_theme_options[title_font]',
			'priority' => 5,
		) ) 
	);
	
	$wp_customize->add_setting( 'nichebarn_theme_options[navi_font]', array(
        'default'           => $default_options['navi_font'],
		'type'           	=> 'option',
        'transport'         => 'postMessage',
        'sanitize_callback' => 'esc_attr'
		)
	);
	$wp_customize->add_control( new Nichebarn_Customize_Font_Control( 
		$wp_customize, 'navi_font', array(
			'label'      => __( 'Navigation Font', 'nichebarn' ),
			'section'    => 'nichebarn_section_fonts',
			'settings'   => 'nichebarn_theme_options[navi_font]',
			'priority' => 6,
		) ) 
	);
	
	$wp_customize->add_setting( 'nichebarn_theme_options[widget_title_font]', array(
        'default'           => $default_options['widget_title_font'],
		'type'           	=> 'option',
        'transport'         => 'postMessage',
        'sanitize_callback' => 'esc_attr'
		)
	);
	$wp_customize->add_control( new Nichebarn_Customize_Font_Control( 
		$wp_customize, 'widget_title_font', array(
			'label'      => __( 'Widget Title Font', 'nichebarn' ),
			'section'    => 'nichebarn_section_fonts',
			'settings'   => 'nichebarn_theme_options[widget_title_font]',
			'priority' => 7,
		) ) 
	);
	
	// Choose Available Fonts
	$wp_customize->add_setting( 'nichebarn_theme_options[available_fonts]', array(
        'default'           => 'default',
		'type'           	=> 'option',
        'transport'         => 'postMessage',
        'sanitize_callback' => 'nichebarn_sanitize_available_fonts'
		)
	);
	$wp_customize->add_control( new Nichebarn_Customize_Font_List_Control( 
		$wp_customize, 'nichebarn_control_available_fonts', array(
			'label'      => __( 'Choose available Fonts', 'nichebarn' ),
			'section'    => 'nichebarn_section_fonts',
			'settings'   => 'nichebarn_theme_options[available_fonts]',
			'choices' => array(
				'default' => __( 'Default Browser Fonts (12)', 'nichebarn' ),
				'favorites' => __( 'Most Popular Fonts (35)', 'nichebarn' ),
				'popular' => __( 'Most Popular Google Fonts (100)', 'nichebarn' ),
				'all' => __( 'All Google Fonts (650)', 'nichebarn' )
				),
			'priority' => 7,
		) ) 
	);
	
}


?>