<?php
/**
 * Register General section, settings and controls for Theme Customizer
 *
 */
// Add Theme Colors section to Customizer
add_action( 'customize_register', 'nichebarn_customize_register_general_settings' );
function nichebarn_customize_register_general_settings( $wp_customize ) {
	// Add Layout Section
	$wp_customize->add_section( 'nichebarn_section_layout', array(
        'title'    => __( 'Theme Layout', 'nichebarn' ),
        'priority' => 1,
		'panel' => 'nichebarn_options_panel' 
		)
	);
	// Add Header Section
	$wp_customize->add_section( 'nichebarn_section_header', array(
        'title'    => __( 'Header Settings', 'nichebarn' ),
        'priority' => 2,
		'panel' => 'nichebarn_options_panel' 
		)
	);
	// Add Sections for Site Title Settings
	$wp_customize->add_section( 'nichebarn_section_titleset', array(
        'title'    => __( 'Site Title Settings', 'nichebarn' ),
        'priority' => 3,
		'panel' => 'nichebarn_options_panel' 
		)
	);
	// Add Footer Layout
	$wp_customize->add_section( 'nichebarn_section_footer', array(
        'title'    => __( 'Footer Settings', 'nichebarn' ),
        'priority' => 9,
		'panel' => 'nichebarn_options_panel' 
		)
	);
	// Add Settings and Controls for Layout
	$wp_customize->add_setting( 'nichebarn_theme_options[layout]', array(
        'default'           => 'right-sidebar',
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_layout'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_layout', array(
        'label'    => __( 'Theme Layout', 'nichebarn' ),
        'section'  => 'nichebarn_section_layout',
        'settings' => 'nichebarn_theme_options[layout]',
        'type'     => 'radio',
		'priority' => 2,
        'choices'  => array(
            'left-sidebar' => __( 'Left Sidebar', 'nichebarn' ),
            'right-sidebar' => __( 'Right Sidebar', 'nichebarn')
			)
		)
	);
	// Theme Layout Control
	$wp_customize->add_setting( 'nichebarn_theme_options[theme_style]', array(
        'default'           => 'boxed-one',
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_theme_style'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_theme_style', array(
        'label'    => __( 'Theme Style', 'nichebarn' ),
        'section'  => 'nichebarn_section_layout',
        'settings' => 'nichebarn_theme_options[theme_style]',
        'type'     => 'radio',
		'priority' => 4,
        'choices'  => array(
            'boxed-one' => __( 'Boxed (Default)', 'nichebarn' ),
            'wide-head' => __( 'Wide Header', 'nichebarn')
			)
		)
	);
	// Add Theme Width
	$wp_customize->add_setting( 'nichebarn_theme_options[theme_width]', array(
        'default'           => 'wd1',
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_theme_width'
		)
	);
    $wp_customize->add_control( 'nichebarn_theme_width', array(
        'label'    => __( 'Theme Width', 'nichebarn' ),
        'section'  => 'nichebarn_section_layout',
        'settings' => 'nichebarn_theme_options[theme_width]',
        'type'     => 'select',
		'priority' => 6,
        'choices'  => array(
            '' 	  => __( 'Default', 'nichebarn' ),
            'wd2' => __( '960px', 'nichebarn'),
			'wd3' => __( '980px', 'nichebarn' ),
            'wd4' => __( '1000px', 'nichebarn' ),
            'wd5' => __( '1050px', 'nichebarn'),
            'wd6' => __( '1080px', 'nichebarn' ),
            'wd7' => __( '1120px', 'nichebarn'),
            'wd8' => __( '1180px', 'nichebarn' ),
            'wd9' => __( '1220px', 'nichebarn'),
            'wd10' => __( '1280px', 'nichebarn' ),
			)
		)
	);
	$wp_customize->add_setting( 'nichebarn_theme_options[extra_functions]', array(
        'default'           => '',
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'esc_attr'
        )
    );
    $wp_customize->add_control( new Nichebarn_Customize_Header_Control(
        $wp_customize, 'nichebarn_control_extra_functions', array(
            'label' => __( 'Extras', 'nichebarn' ),
            'section' => 'nichebarn_section_layout',
            'settings' => 'nichebarn_theme_options[extra_functions]',
            'priority' => 7
            )
        )
    );
	// Link to Top
	$wp_customize->add_setting( 'nichebarn_theme_options[link_to_top]', array(
        'default'           => true,
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_checkbox'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_link_to_top', array(
        'label'    => __( 'Display Scroll to Top button.', 'nichebarn' ),
        'section'  => 'nichebarn_section_layout',
        'settings' => 'nichebarn_theme_options[link_to_top]',
        'type'     => 'checkbox',
		'priority' => 8,
		)
	);
// Add Footer Widget Settings
	$wp_customize->add_setting( 'nichebarn_theme_options[fwidgets]', array(
        'default'           => '3',
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_fwidgets'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_fwidgets', array(
        'label'    => __( 'Footer Widgets Layout', 'nichebarn' ),
        'section'  => 'nichebarn_section_footer',
        'settings' => 'nichebarn_theme_options[fwidgets]',
        'type'     => 'radio',
		'priority' => 2,
        'choices'  => array(
            '0' => __( 'No Widget', 'nichebarn' ),
            '1' => __( '1 Column', 'nichebarn'),
            '2' => __( '2 Columns', 'nichebarn' ),
            '3' => __( '3 Columns', 'nichebarn'),
            '4' => __( '4 Columns', 'nichebarn'),
			)
		)
	);
	// Add Footer Settings
	$wp_customize->add_setting( 'nichebarn_theme_options[footer_text]', array(
        'default'           => '',
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_footer_text'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_footer_text', array(
        'label'    => __( 'Footer Text', 'nichebarn' ),
        'section'  => 'nichebarn_section_footer',
        'settings' => 'nichebarn_theme_options[footer_text]',
        'type'     => 'textarea',
		'priority' => 4,
		)
	);
	$wp_customize->add_setting( 'nichebarn_theme_options[credit_link]', array(
        'default'           => true,
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_checkbox'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_credit_link', array(
        'label'    => __( 'Display credit link to Nichebarn on footer.', 'nichebarn' ),
        'section'  => 'nichebarn_section_footer',
        'settings' => 'nichebarn_theme_options[credit_link]',
        'type'     => 'checkbox',
		'priority' => 6,
		)
	);
	$wp_customize->add_setting( 'nichebarn_theme_options[track_code]', array(
        'default'           => '',
		'type'           	=> 'option',
        'transport'         => 'postMessage',
        'sanitize_callback' => 'nichebarn_sanitize_track_code'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_track_code', array(
        'label'    => __( 'Footer Code', 'nichebarn' ),
        'section'  => 'nichebarn_section_footer',
        'settings' => 'nichebarn_theme_options[track_code]',
        'type'     => 'textarea',
		'description' => 'For Google Analytics, tracking code, etc.',
		'priority' => 8,
		)
	);
}


?>