<?php
/**
 * Register Header Content section, settings and controls for Theme Customizer
 *
 */
// Add Theme Colors section to Customizer
add_action( 'customize_register', 'nichebarn_customize_register_header_settings' );

function nichebarn_customize_register_header_settings( $wp_customize ) {
	// Add Upload logo image setting
	$wp_customize->add_setting( 'nichebarn_theme_options[header_logo]', array(
        'default'           => '',
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'esc_url'
		)
	);
	$wp_customize->add_control( new WP_Customize_Image_Control(
		$wp_customize, 'nichebarn_control_header_logo', array(
			'label'    => __( 'Logo Image (Replaces Site Title)', 'nichebarn' ),
			'section'  => 'title_tagline',
			'settings' => 'nichebarn_theme_options[header_logo]',
			'priority' => 2,
			)
		)
	);
	// Add Header Tagline option
	$wp_customize->add_setting( 'nichebarn_theme_options[header_tagline]', array(
        'default'           => false,
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_checkbox'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_header_tagline', array(
        'label'    => __( 'Display tagline below site title.', 'nichebarn' ),
        'section'  => 'title_tagline',
        'settings' => 'nichebarn_theme_options[header_tagline]',
        'type'     => 'checkbox',
		'priority' => 10,
		)
	);
	// Add Upload Favicon
	$wp_customize->add_setting( 'nichebarn_theme_options[site_favi]', array(
        'default'           => '',
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'esc_url'
		)
	);
	$wp_customize->add_control( new WP_Customize_Image_Control(
		$wp_customize, 'nichebarn_control_site_favi', array(
			'label'    => __( 'Favicon (32px by 32px)', 'nichebarn' ),
			'section'  => 'title_tagline',
			'settings' => 'nichebarn_theme_options[site_favi]',
			'priority' => 12,
			)
		)
	);
	
// Add Settings and Controls for Header
	$wp_customize->add_setting( 'nichebarn_theme_options[header_icons]', array(
        'default'           => false,
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_checkbox'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_header_icons', array(
        'label'    => __( 'Display Social Icons on top menu.', 'nichebarn' ),
        'section'  => 'nichebarn_section_header',
        'settings' => 'nichebarn_theme_options[header_icons]',
        'type'     => 'checkbox',
		'priority' => 5
		)
	);	
	// Move Down Top Navbar
	$wp_customize->add_setting( 'nichebarn_theme_options[topnav_down]', array(
        'default'           => false,
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_checkbox'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_topnav_down', array(
        'label'    => __( 'Move Down Top Navbar', 'nichebarn' ),
        'section'  => 'nichebarn_section_header',
        'settings' => 'nichebarn_theme_options[topnav_down]',
        'type'     => 'checkbox',
		'priority' => 6
		)
	);	
	// Sticky Tokey
	$wp_customize->add_setting( 'nichebarn_theme_options[sticky_navi]', array(
        'default'           => 0,
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_checkbox'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_sticky_navi', array(
        'label'    => __( 'Enable Sticky Navigation', 'pmthemes' ),
        'section'  => 'nichebarn_section_header',
        'settings' => 'nichebarn_theme_options[sticky_navi]',
        'type'     => 'checkbox',
		'priority' => 8,
		)
	);
	// Search Icon
	$wp_customize->add_setting( 'nichebarn_theme_options[search_icon]', array(
        'default'           => true,
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_checkbox'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_search_icon', array(
        'label'    => __( 'Enable Search on Main Menu', 'pmthemes' ),
        'section'  => 'nichebarn_section_header',
        'settings' => 'nichebarn_theme_options[search_icon]',
        'type'     => 'checkbox',
		'priority' => 9,
		)
	);
	// Enable Facebook Open Graph Meta
	$wp_customize->add_setting( 'nichebarn_theme_options[fb_meta_graph]', array(
        'default'           => true,
		'type'           	=> 'option',
        'transport'         => 'postMessage',
        'sanitize_callback' => 'nichebarn_sanitize_checkbox'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_fb_meta_graph', array(
        'label'    => __( 'Enable FB Open Graph Meta', 'pmthemes' ),
        'section'  => 'nichebarn_section_header',
        'settings' => 'nichebarn_theme_options[fb_meta_graph]',
        'type'     => 'checkbox',
		'priority' => 10,
		)
	);
	// Disable that Emoji
	$wp_customize->add_setting( 'nichebarn_theme_options[wp_emoji]', array(
        'default'           => true,
		'type'           	=> 'option',
        'transport'         => 'postMessage',
        'sanitize_callback' => 'nichebarn_sanitize_checkbox'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_wp_emoji', array(
        'label'    => __( 'Disable Emoji', 'pmthemes' ),
        'section'  => 'nichebarn_section_header',
        'settings' => 'nichebarn_theme_options[wp_emoji]',
        'type'     => 'checkbox',
		'priority' => 11,
		)
	);
	// FB APP ID
	$wp_customize->add_setting( 'nichebarn_theme_options[fb_app_id]', array(
        'default'           => '621021928047856',
		'type'           	=> 'option',
        'transport'         => 'postMessage',
        'sanitize_callback' => 'nichebarn_sanitize_read_text'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_fb_app_id', array(
        'label'    => __( 'FB APP ID', 'pmthemes' ),
        'section'  => 'nichebarn_section_header',
        'settings' => 'nichebarn_theme_options[fb_app_id]',
        'type'     => 'text',
		'priority' => 12,
		)
	);
	// Header Code
	$wp_customize->add_setting( 'nichebarn_theme_options[header_code]', array(
        'default'           => '',
		'type'           	=> 'option',
        'transport'         => 'postMessage',
        'sanitize_callback' => 'nichebarn_sanitize_header_code'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_header_code', array(
        'label'    => __( 'Header Code', 'pmthemes' ),
        'section'  => 'nichebarn_section_header',
        'settings' => 'nichebarn_theme_options[header_code]',
        'type'     => 'textarea',
		'description' => 'For Google Verification Code, etc.',
		'priority' => 12,
		)
	);
	
// Add Settings and Controls for Title Settings
	// Enable Header Custom Style
	$wp_customize->add_setting( 'nichebarn_theme_options[header_padding]', array(
        'default'           => false,
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_checkbox'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_header_padding', array(
        'label'    => __( 'Enable Site Title Settings', 'nichebarn' ),
        'section'  => 'nichebarn_section_titleset',
        'settings' => 'nichebarn_theme_options[header_padding]',
        'type'     => 'checkbox',
		'description' => 'Set Title font size & padding. Balance logo/title width and banner width.',
		'priority' => 2,
		)
	);
	// Set Title Font Size
	$wp_customize->add_setting( 'nichebarn_theme_options[title_font_size]', array(
        'default'           => '37',
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_read_text'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_title_font_size', array(
        'label'    => __( 'Title Font Size (20-70)', 'nichebarn' ),
        'section'  => 'nichebarn_section_titleset',
        'settings' => 'nichebarn_theme_options[title_font_size]',
        'type'     => 'text',
		'priority' => 3,
		)
	);
	// Set Title Font Spacing
	$wp_customize->add_setting( 'nichebarn_theme_options[title_font_space]', array(
        'default'           => '3',
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_read_text'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_title_font_space', array(
        'label'    => __( 'Title Font Spacing (0-5)', 'nichebarn' ),
        'section'  => 'nichebarn_section_titleset',
        'settings' => 'nichebarn_theme_options[title_font_space]',
        'type'     => 'text',
		'priority' => 4,
		)
	);
	// Title top padding
	$wp_customize->add_setting( 'nichebarn_theme_options[title_top_padding]', array(
        'default'           => '15',
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_read_text'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_title_top_padding', array(
        'label'    => __( 'Title Top Padding (0-25)', 'nichebarn' ),
        'section'  => 'nichebarn_section_titleset',
        'settings' => 'nichebarn_theme_options[title_top_padding]',
        'type'     => 'text',
		'priority' => 5,
		)
	);
	// Logo/Title Width
	$wp_customize->add_setting( 'nichebarn_theme_options[logo_title_width]', array(
        'default'           => '37.5',
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_read_text'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_logo_title_width', array(
        'label'    => __( 'Title/Logo Width (35-100)', 'nichebarn' ),
        'section'  => 'nichebarn_section_titleset',
        'settings' => 'nichebarn_theme_options[logo_title_width]',
        'type'     => 'text',
		'priority' => 6,
		)
	);
	// Header Banner Width
	$wp_customize->add_setting( 'nichebarn_theme_options[header_banner_width]', array(
        'default'           => '61.5',
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_read_text'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_header_banner_width', array(
        'label'    => __( 'Header Banner Width (35-100)', 'nichebarn' ),
        'section'  => 'nichebarn_section_titleset',
        'settings' => 'nichebarn_theme_options[header_banner_width]',
        'type'     => 'text',
		'priority' => 7,
		)
	);	

}
?>