<?php
/**
 * Register Post Settings section, settings and controls for Theme Customizer
 *
 */

// Add Theme Colors section to Customizer
add_action( 'customize_register', 'nichebarn_customize_register_post_settings' );

function nichebarn_customize_register_post_settings( $wp_customize ) {
	// Add Sections for Post Settings
	$wp_customize->add_section( 'nichebarn_section_post', array(
        'title'    => __( 'Post Settings', 'nichebarn' ),
        'priority' => 7,
		'panel' => 'nichebarn_options_panel' 
		)
	);
	// Add Sections for Related Posts
	$wp_customize->add_section( 'nichebarn_section_related', array(
        'title'    => __( 'Related Posts', 'nichebarn' ),
        'priority' => 8,
		'panel' => 'nichebarn_options_panel' 
		)
	);
	
	// Add Settings and Controls for Posts
	// Add Post Dates Headline
	$wp_customize->add_setting( 'nichebarn_theme_options[post_dates]', array(
        'default'           => '',
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'esc_attr'
        )
    );
    $wp_customize->add_control( new Nichebarn_Customize_Header_Control(
        $wp_customize, 'nichebarn_control_post_dates', array(
            'label' => __( 'Post Dates', 'nichebarn' ),
            'section' => 'nichebarn_section_post',
            'settings' => 'nichebarn_theme_options[post_dates]',
            'priority' => 1
            )
        )
    );
	$wp_customize->add_setting( 'nichebarn_theme_options[show_post_dates]', array(
        'default'           => false,
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_checkbox'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_hide_post_dates', array(
        'label'    => __( 'Show Post Dates.', 'nichebarn' ),
        'section'  => 'nichebarn_section_post',
        'settings' => 'nichebarn_theme_options[show_post_dates]',
        'type'     => 'checkbox',
		'priority' => 2,
		)
	);	
	$wp_customize->add_setting( 'nichebarn_theme_options[posts_length]', array(
        'default'           => 'excerpt',
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_post_length'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_posts_length', array(
        'label'    => __( 'Post Length on archives', 'nichebarn' ),
        'section'  => 'nichebarn_section_post',
        'settings' => 'nichebarn_theme_options[posts_length]',
        'type'     => 'radio',
		'priority' => 3,
        'choices'  => array(
            'index' => __( 'Show full posts', 'nichebarn' ),
            'excerpt' => __( 'Show post summaries (excerpt)', 'nichebarn' )
			)
		)
	);
	
	// Add Post Images Headline
	$wp_customize->add_setting( 'nichebarn_theme_options[post_images]', array(
        'default'           => '',
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'esc_attr'
        )
    );
    $wp_customize->add_control( new Nichebarn_Customize_Header_Control(
        $wp_customize, 'nichebarn_control_post_images', array(
            'label' => __( 'Post Images', 'nichebarn' ),
            'section' => 'nichebarn_section_post',
            'settings' => 'nichebarn_theme_options[post_images]',
            'priority' => 4
            )
        )
    );
	$wp_customize->add_setting( 'nichebarn_theme_options[post_thumbnails_index]', array(
        'default'           => true,
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_checkbox'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_posts_thumbnails_index', array(
        'label'    => __( 'Display featured images on archive pages', 'nichebarn' ),
        'section'  => 'nichebarn_section_post',
        'settings' => 'nichebarn_theme_options[post_thumbnails_index]',
        'type'     => 'checkbox',
		'priority' => 5
		)
	);

	$wp_customize->add_setting( 'nichebarn_theme_options[post_thumbnails_single]', array(
        'default'           => false,
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_checkbox'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_posts_thumbnails_single', array(
        'label'    => __( 'Display featured images on single posts', 'nichebarn' ),
        'section'  => 'nichebarn_section_post',
        'settings' => 'nichebarn_theme_options[post_thumbnails_single]',
        'type'     => 'checkbox',
		'priority' => 6
		)
	);
	$wp_customize->add_setting( 'nichebarn_theme_options[excerpt_text]', array(
        'default'           => 'Read more',
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_read_text'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_excerpt_text', array(
        'label'    => __( 'Read More Text', 'nichebarn' ),
        'section'  => 'nichebarn_section_post',
        'settings' => 'nichebarn_theme_options[excerpt_text]',
        'type'     => 'text',
		'priority' => 7
		)
	);
	
// Add Related Posts Settings
	$wp_customize->add_setting( 'nichebarn_theme_options[related_posts_single]', array(
        'default'           => false,
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_checkbox'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_related_posts_single', array(
        'label'    => __( 'Display related posts?', 'nichebarn' ),
        'section'  => 'nichebarn_section_related',
        'settings' => 'nichebarn_theme_options[related_posts_single]',
        'type'     => 'checkbox',
		'priority' => 2
		)
	);
	$wp_customize->add_setting( 'nichebarn_theme_options[related_posts_thumb]', array(
        'default'           => true,
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_checkbox'
		)
	);	
    $wp_customize->add_control( 'nichebarn_control_related_posts_thumb', array(
        'label'    => __( 'Display thumbnails?', 'nichebarn' ),
        'section'  => 'nichebarn_section_related',
        'settings' => 'nichebarn_theme_options[related_posts_thumb]',
        'type'     => 'checkbox',
		'priority' => 3
		)
	);
	$wp_customize->add_setting( 'nichebarn_theme_options[related_posts_excerpt]', array(
        'default'           => false,
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_checkbox'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_related_posts_excerpt', array(
        'label'    => __( 'Display excerpts?', 'nichebarn' ),
        'section'  => 'nichebarn_section_related',
        'settings' => 'nichebarn_theme_options[related_posts_excerpt]',
        'type'     => 'checkbox',
		'priority' => 4
		)
	);
	$wp_customize->add_setting( 'nichebarn_theme_options[related_excerpt_length]', array(
        'default'           => '55',
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_read_text'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_related_excerpt_length', array(
        'label'    => __( 'Excerpt Length', 'nichebarn' ),
        'section'  => 'nichebarn_section_related',
        'settings' => 'nichebarn_theme_options[related_excerpt_length]',
        'type'     => 'text',
		'priority' => 5
		)
	);
	$wp_customize->add_setting( 'nichebarn_theme_options[related_post_count]', array(
        'default'           => '4',
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_read_text'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_related_post_count', array(
        'label'    => __( 'Number of Related Posts', 'nichebarn' ),
        'section'  => 'nichebarn_section_related',
        'settings' => 'nichebarn_theme_options[related_post_count]',
        'type'     => 'text',
		'priority' => 6
		)
	);
	$wp_customize->add_setting( 'nichebarn_theme_options[related_header_title]', array(
        'default'           => 'Related Posts',
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_read_text'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_related_header_title', array(
        'label'    => __( 'Related Header Title', 'nichebarn' ),
        'section'  => 'nichebarn_section_related',
        'settings' => 'nichebarn_theme_options[related_header_title]',
        'type'     => 'text',
		'priority' => 7
		)
	);
	$wp_customize->add_setting( 'nichebarn_theme_options[related_post_style]', array(
        'default'           => 'four-cols',
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_related_post_style'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_related_post_style', array(
        'label'    => __( 'Display Style', 'nichebarn' ),
        'section'  => 'nichebarn_section_related',
        'settings' => 'nichebarn_theme_options[related_post_style]',
        'type'     => 'radio',
		'priority' => 8,
        'choices'  => array(
            'four-cols' => __( 'Four Columns (Default)', 'nichebarn' ),
			'three-cols' => __( 'Three Columns', 'nichebarn' ),
			'two-cols' => __( 'Two Columns', 'nichebarn' ),
            'simple-list' => __( 'One Column', 'nichebarn')
			)
		)
	);

}
?>