<?php
/**
 * Register Post Slider section, settings and controls for Theme Customizer
 *
 */

// Add Theme Colors section to Customizer
add_action( 'customize_register', 'nichebarn_customize_register_slider_settings' );

function nichebarn_customize_register_slider_settings( $wp_customize ) {

	// Add Sections for Slider Settings
	$wp_customize->add_section( 'nichebarn_section_slider', array(
        'title'    => __( 'Slider Settings', 'nichebarn' ),
		'description' => __( 'The slideshow displays your featured posts, which you can configure on the "Featured Content" section above.', 'nichebarn' ),
        'priority' => 6,
		'panel' => 'nichebarn_options_panel' 
		)
	);
	// Add settings and controls for Post Slider
	$wp_customize->add_setting( 'nichebarn_theme_options[slider_activated]', array(
        'default'           => '',
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'esc_attr'
        )
    );
    $wp_customize->add_control( new Nichebarn_Customize_Header_Control(
        $wp_customize, 'nichebarn_control_slider_activated', array(
            'label' => __( 'Activate Featured Post Slider', 'nichebarn' ),
            'section' => 'nichebarn_section_slider',
            'settings' => 'nichebarn_theme_options[slider_activated]',
            'priority' => 1
            )
        )
    );
	$wp_customize->add_setting( 'nichebarn_theme_options[slider_activated_front_page]', array(
        'default'           => 1,
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_checkbox'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_slider_activated_frontpage', array(
        'label'    => __( 'Display Slider on Magazine Front Page template.', 'nichebarn' ),
        'section'  => 'nichebarn_section_slider',
        'settings' => 'nichebarn_theme_options[slider_activated_front_page]',
        'type'     => 'checkbox',
		'priority' => 2
		)
	);
	$wp_customize->add_setting( 'nichebarn_theme_options[slider_activated_blog]', array(
        'default'           => 0,
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_checkbox'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_slider_activated_blog', array(
        'label'    => __( 'Display Slider on normal blog index.', 'nichebarn' ),
        'section'  => 'nichebarn_section_slider',
        'settings' => 'nichebarn_theme_options[slider_activated_blog]',
        'type'     => 'checkbox',
		'priority' => 3
		)
	);
	$wp_customize->add_setting( 'nichebarn_theme_options[show_slider_content]', array(
        'default'           => 1,
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_checkbox'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_show_slider_content', array(
        'label'    => __( 'Display Slider Content.', 'nichebarn' ),
        'section'  => 'nichebarn_section_slider',
        'settings' => 'nichebarn_theme_options[show_slider_content]',
        'type'     => 'checkbox',
		'priority' => 4
		)
	);

	$wp_customize->add_setting( 'nichebarn_theme_options[slider_animation]', array(
        'default'           => 'fade',
		'type'           	=> 'option',
        'transport'         => 'refresh',
        'sanitize_callback' => 'nichebarn_sanitize_slider_animation'
		)
	);
    $wp_customize->add_control( 'nichebarn_control_slider_animation', array(
        'label'    => __( 'Slider Animation', 'nichebarn' ),
        'section'  => 'nichebarn_section_slider',
        'settings' => 'nichebarn_theme_options[slider_animation]',
        'type'     => 'radio',
		'priority' => 4,
        'choices'  => array(
            'horizontal' => __( 'Horizontal Slider', 'nichebarn' ),
            'fade' => __( 'Fade Slider', 'nichebarn' )
			)
		)
	);
	
}

?>