<?php
// Load default style.css and Javascripts
add_action('wp_enqueue_scripts', 'nichebarn_enqueue_scripts');
if ( ! function_exists( 'nichebarn_enqueue_scripts' ) ):
function nichebarn_enqueue_scripts() {
	// Get Theme Options from Database
	$theme_options = nichebarn_theme_options();
	// Register and Enqueue Stylesheet
	wp_enqueue_style('nichebarn-stylesheet', get_stylesheet_uri());
	// Register Fonts
	//wp_enqueue_style( 'nichebarn-fonts', get_template_directory_uri().'/css/fonts/css/font-awesome.css');
	wp_enqueue_style( 'nichebarn-fonts', get_template_directory_uri().'/css/fonts/css/fontello.css');
	// Register and Enqueue FlexSlider JS and CSS if necessary
	if ( ( isset($theme_options['slider_activated_blog']) and $theme_options['slider_activated_blog'] == true )
		|| ( isset($theme_options['slider_activated_front_page']) and $theme_options['slider_activated_front_page'] == true ) ) :
		// FlexSlider CSS
		wp_enqueue_style('nichebarn-flexslider', NICHEBARN_URI . '/css/flexslider.css');
		// FlexSlider JS
		wp_enqueue_script('nichebarn-jquery-flexslider', NICHEBARN_URI .'/js/jquery.flexslider-min.js', array('jquery'));
		// Register and enqueue slider.js
		wp_enqueue_script('nichebarn-jquery-frontpage_slider', NICHEBARN_URI .'/js/slider.js', array('nichebarn-jquery-flexslider'));
	endif;
	// Register and enqueue navigation.js
	wp_enqueue_script('nichebarn-jquery-navigation', NICHEBARN_URI .'/js/navigation.js', array('jquery'));
	// Register and Enqueue Font
	if ( !( isset($theme_options['deactivate_google_fonts']) and $theme_options['deactivate_google_fonts'] == false ) ) :
	wp_enqueue_style('nichebarn-default-fonts', nichebarn_fonts_url(), array(), null );
	endif;
	wp_add_inline_style( 'nichebarn-style', $styles );
	
    wp_enqueue_script( 'fancybox', get_template_directory_uri() . '/inc/lightbox/js/jquery.fancybox.min.js', array( 'jquery' ), false, true );
    wp_enqueue_script( 'lightbox', get_template_directory_uri() . '/inc/lightbox/js/lightbox.js', array( 'fancybox' ), false, true );
    wp_enqueue_style( 'lightbox-style', get_template_directory_uri() . '/inc/lightbox/css/jquery.fancybox.min.css' );
}
endif;
// Load comment-reply.js if comment form is loaded and threaded comments activated
add_action( 'comment_form_before', 'nichebarn_enqueue_comment_reply' );
function nichebarn_enqueue_comment_reply() {
	if( get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
/*
* Retrieve Font URL to register default Google Fonts
*/
function nichebarn_fonts_url() {
		// Set Default Fonts
		$font_families = array('Raleway:400,700', 'Bitter'); 
		// Set Google Font Query Args
		$query_args = array(
			'family' => urlencode( implode( '|', $font_families ) ),
			'subset' => urlencode( 'latin,latin-ext' ),
		);
		// Create Fonts URL
		$fonts_url = add_query_arg( $query_args, '//fonts.googleapis.com/css' );
		return apply_filters( 'nichebarn_google_fonts_url', $fonts_url );
}
// Setup Function: Registers support for various WordPress features
add_action( 'after_setup_theme', 'nichebarn_setup' );
if ( ! function_exists( 'nichebarn_setup' ) ):
function nichebarn_setup() {
	// Set Content Width
	global $content_width;
	if ( ! isset( $content_width ) )
		$content_width = 860;
	// init Localization
	load_theme_textdomain('nichebarn', NICHEBARN_DIR . '/languages' );
	// Add Theme Support
	add_theme_support('post-thumbnails');
	add_theme_support('automatic-feed-links');
	add_theme_support('title-tag');
	add_editor_style();
	// Add Custom Background
	add_theme_support('custom-background', array(
		'default-color' => 'e5e5e5',
		'default-attachment' => 'fixed',
		'default-image' => NICHEBARN_URI . '/images/bg.jpg'));
	// Add Custom Header
	add_theme_support('custom-header', array(
		'header-text' => false,
		'width'	=> 1340,
		'height' => 250,
	'default-repeat'         => '',
	'default-position-x'     => '',
		'flex-width' => true,
		'flex-height' => true));
	// Enable support for WooCommerce
	add_theme_support( 'woocommerce' );
	// Enable support for Widget Plugin
	add_theme_support( 'pmthemes' );
	// Register Navigation Menus
	register_nav_menu( 'primary', __('Main Navigation', 'nichebarn') );
	register_nav_menu( 'secondary', __('Top Navigation', 'nichebarn') );
	register_nav_menu( 'sticky', __('Sticky Navigation', 'nichebarn') );
	register_nav_menu( 'footer', __('Footer Navigation', 'nichebarn') );
	// Register Social Icons Menu
	register_nav_menu( 'social', __('Social Icons', 'nichebarn') );
	// Register Add On Widgets
	register_widget('Nichebarn_Popular_Posts_Widget');
	register_widget('Nichebarn_Recent_Comments_Widget');
	register_widget('Nichebarn_Recent_Posts_Widget');
	register_widget('Nichebarn_Social_Icons_Widget');
	register_widget('Nichebarn_Tabbed_Content_Widget');
}
endif;
// Add custom Image Sizes
add_action( 'after_setup_theme', 'nichebarn_add_image_sizes' );
if ( ! function_exists( 'nichebarn_add_image_sizes' ) ):
function nichebarn_add_image_sizes() {
	// Add Custom Header Image Size
	add_image_size( 'custom_header_image', 1340, 250, true);
	// Add Featured Image Size
	add_image_size( 'featured_image', 220, 220, true);
	add_image_size( 'featured_image_posts', 800, 500, true);
	// Add Slider Image Size
	add_image_size( 'slider_image', 800, 400, true);
	// Add Frontpage Thumbnail Sizes
	add_image_size( 'category_posts_wide_thumb', 600, 240, true);
	add_image_size( 'category_posts_small_thumb', 150, 150, true);
	// Add Widget Post Thumbnail Size
	add_image_size( 'widget_post_thumb', 75, 75, true);
}
endif;
// Register Sidebars
add_action( 'widgets_init', 'nichebarn_register_sidebars' );
if ( ! function_exists( 'nichebarn_register_sidebars' ) ):
function nichebarn_register_sidebars() {
	register_sidebar( array(
		'name' => __( 'Main Sidebar', 'nichebarn' ),
		'id' => 'sidebar',
		'description' => __( 'Appears on posts and pages except front page and fullwidth template.', 'nichebarn' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s clearfix">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="widgettitle"><span>',
		'after_title' => '</span></h3>',
	));
	register_sidebar( array(
		'name' => esc_html__( 'Sidebar Sub Column Left', 'pmthemes' ),
		'id' => 'sidebar2',
		'description' => esc_html__( 'Appears on left side under main sidebar.', 'pmthemes' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s clearfix">',
		'after_widget' => '</aside>',
		'before_title' => '<h4 class="widgettitle"><span>',
		'after_title' => '</span></h4>',
	));
	register_sidebar( array(
		'name' => esc_html__( 'Sidebar Sub Column Right', 'pmthemes' ),
		'id' => 'sidebar3',
		'description' => esc_html__( 'Appears on right side under main sidebar.', 'pmthemes' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s clearfix">',
		'after_widget' => '</aside>',
		'before_title' => '<h4 class="widgettitle"><span>',
		'after_title' => '</span></h4>',
	));
	register_sidebar( array(
		'name' => __( 'Header Content', 'nichebarn' ),
		'id' => 'head-content',
		'description' => __( 'Place your own content on the right side header. Ad block, search form, text, etc.', 'nichebarn' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s clearfix">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="widgettitle"><span>',
		'after_title' => '</span></h3>',
	));
	register_sidebar( array(
		'name' => __( 'Magazine Front Page', 'nichebarn' ),
		'id' => 'frontpage-magazine',
		'description' => __( 'Appears on Magazine Front Page page template only. You can use the Home Posts widgets here.', 'nichebarn' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',

		'after_widget' => '</div>',
		'before_title' => '<h3 class="widgettitle">',
		'after_title' => '</h3>',
	));
	register_sidebar( array(
		'name' => __( 'Footer Widget 1', 'nichebarn' ),
		'id' => 'footer-widgets-1',
		'description' => __( 'Appears on footer widgets.', 'nichebarn' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="widgettitle"><span>',
		'after_title' => '</span></h3>'
	));
	register_sidebar( array(
		'name' => __( 'Footer Widget 2', 'nichebarn' ),
		'id' => 'footer-widgets-2',
		'description' => __( 'Appears on footer widgets.', 'nichebarn' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="widgettitle"><span>',
		'after_title' => '</span></h3>'
	));
	register_sidebar( array(
		'name' => __( 'Footer Widget 3', 'nichebarn' ),
		'id' => 'footer-widgets-3',
		'description' => __( 'Appears on footer widgets.', 'nichebarn' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="widgettitle"><span>',
		'after_title' => '</span></h3>'
	));
	register_sidebar( array(
		'name' => __( 'Footer Widget 4', 'nichebarn' ),
		'id' => 'footer-widgets-4',
		'description' => __( 'Appears on footer widgets.', 'nichebarn' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="widgettitle"><span>',
		'after_title' => '</span></h3>'
	));

}
endif;
// Add title tag for older WordPress versions
if ( ! function_exists( '_wp_render_title_tag' ) ) :
	add_action( 'wp_head', 'nichebarn_wp_title' );
	function nichebarn_wp_title() { ?>	
		<title><?php wp_title( '|', true, 'right' ); ?></title>
<?php } endif;
// Add Default Menu Fallback Function
function nichebarn_default_menu() {
	echo '<ul id="nav-menu" class="nav-menu">'. wp_list_pages('title_li=&echo=0') .'</ul>';
}
// Get Featured Posts
function nichebarn_get_featured_content() {	return apply_filters( 'nichebarn_get_featured_content', false );
}
// Change Excerpt Length
add_filter('excerpt_length', 'nichebarn_excerpt_length');
function nichebarn_excerpt_length($length) {
    return 77;
}
// Slideshow Excerpt Length
function nichebarn_slideshow_excerpt_length($length) {
    return 15;
}
// Frontpage Category Excerpt Length
function nichebarn_frontpage_category_excerpt_length($length) {
    return 19;
}
// Post Boxed Excerpt Length
function nichebarn_postsbox_excerpt_length($length) {
    return 12;
}
// Post Boxed First Post Excerpt Length
function nichebarn_postsbox_first_excerpt_length($length) {
    return 45;
}
function nichebarn_related_posts_excerpt($length) {
$theme_options = nichebarn_theme_options();
    return $theme_options['related_excerpt_length'];
}
add_filter( 'body_class', 'nichebarn_body_classes' );
function nichebarn_body_classes( $classes ) {
	$theme_options = nichebarn_theme_options();
	if ( isset($theme_options['layout']) and $theme_options['layout'] == 'left-sidebar' ) :
		$classes[] = 'rlayout';
	endif;
	if ( isset($theme_options['theme_width']) and $theme_options['theme_width'] == 'wd2' ) :
		$classes[] = 'wd2';
	elseif ( isset($theme_options['theme_width']) and $theme_options['theme_width'] == 'wd3' ) :
		$classes[] = 'wd3';
	elseif ( isset($theme_options['theme_width']) and $theme_options['theme_width'] == 'wd4' ) :
		$classes[] = 'wd4';
	elseif ( isset($theme_options['theme_width']) and $theme_options['theme_width'] == 'wd5' ) :
		$classes[] = 'wd5';
	elseif ( isset($theme_options['theme_width']) and $theme_options['theme_width'] == 'wd6' ) :
		$classes[] = 'wd6';
	elseif ( isset($theme_options['theme_width']) and $theme_options['theme_width'] == 'wd7' ) :
		$classes[] = 'wd7';
	elseif ( isset($theme_options['theme_width']) and $theme_options['theme_width'] == 'wd8' ) :
		$classes[] = 'wd8';
	elseif ( isset($theme_options['theme_width']) and $theme_options['theme_width'] == 'wd9' ) :
		$classes[] = 'wd9';
	elseif ( isset($theme_options['theme_width']) and $theme_options['theme_width'] == 'wd10' ) :
		$classes[] = 'wd10';
	endif;
	if ( isset($theme_options['theme_style']) and $theme_options['theme_style'] == 'wide-head' ) :
		$classes[] = 'wide-header';
	endif;
	return $classes;
}
// Custom Template for comments and pingbacks.
if ( ! function_exists( 'nichebarn_list_comments' ) ):
function nichebarn_list_comments($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment;
	if( $comment->comment_type == 'pingback' or $comment->comment_type == 'trackback' ) : ?>
		<li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">
			<p><?php _e( 'Pingback:', 'nichebarn' ); ?> <?php comment_author_link(); ?>
			<?php edit_comment_link( __( '(Edit)', 'nichebarn' ), '<span class="edit-link">', '</span>' ); ?>
			</p>
	<?php else : ?>
		<li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">
			<div id="div-comment-<?php comment_ID(); ?>" class="comment-body">
				<div class="comment-author vcard">
					<?php echo get_avatar( $comment, 56 ); ?>
					<?php printf(__('<span class="fn">%s</span>', 'nichebarn'), get_comment_author_link()) ?>
				</div>
		<?php if ($comment->comment_approved == '0') : ?>
				<p class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'nichebarn' ); ?></p>
		<?php endif; ?>
				<div class="comment-meta commentmetadata">
					<a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>"><?php printf(__('%1$s at %2$s', 'nichebarn'), get_comment_date(),  get_comment_time()) ?></a>
					<?php edit_comment_link(__('(Edit)', 'nichebarn'),'  ','') ?>
				</div>
				<div class="comment-content"><?php comment_text(); ?></div>
				<div class="reply">
					<?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
				</div>
			</div>
	<?php endif; }
endif; 
if ( isset($theme_options['fb_meta_graph']) and $theme_options['fb_meta_graph'] == true ) :
add_opengraph_doctype(); 
insert_fb_in_head();
endif; 
/*** Disable the emoji's */
function disable_emojis() {
	remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
	remove_action( 'admin_print_scripts', 'print_emoji_detection_script' );
	remove_action( 'wp_print_styles', 'print_emoji_styles' );
	remove_action( 'admin_print_styles', 'print_emoji_styles' );	
	remove_filter( 'the_content_feed', 'wp_staticize_emoji' );
	remove_filter( 'comment_text_rss', 'wp_staticize_emoji' );	
	remove_filter( 'wp_mail', 'wp_staticize_emoji_for_email' );
	add_filter( 'tiny_mce_plugins', 'disable_emojis_tinymce' );
}
add_action( 'init', 'disable_emojis' );
/**
 * Filter function used to remove the tinymce emoji plugin.
 * 
 * @param    array  $plugins  
 * @return   array             Difference betwen the two arrays
 */
function disable_emojis_tinymce( $plugins ) {
	if ( is_array( $plugins ) ) {
		return array_diff( $plugins, array( 'wpemoji' ) );
	} else {
		return array();
	}
}
/*** Disable Header Generators */
remove_action( 'wp_head', 'wp_generator' ) ;
remove_action( 'wp_head', 'wlwmanifest_link' ) ;
remove_action( 'wp_head', 'rsd_link' ) ;
?>